Update of /cvsroot/plexus/plexus-container-new/src/java/org/apache/plexus/lifecycle/avalon
In directory eng.werken.com:/tmp/cvs-serv7587
Modified Files:
AvalonLifecycleHandler.java
Log Message:
o Just making changes while chatting with Bob. We will
use the term segment to denote a grouping of phases in
the lifecycle. So for example in the beginSegment for Avalon
we have logenabled, contextualize, service ...
Index: AvalonLifecycleHandler.java
===================================================================
RCS file: /cvsroot/plexus/plexus-container-new/src/java/org/apache/plexus/lifecycle/avalon/AvalonLifecycleHandler.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -d -r1.2 -r1.3
--- AvalonLifecycleHandler.java 23 Apr 2003 03:57:13 -0000 1.2
+++ AvalonLifecycleHandler.java 24 Apr 2003 13:21:59 -0000 1.3
@@ -18,7 +18,7 @@
* the documentation and/or other materials provided with the
* distribution.
*
* 3. The end-user documentation included with the redistribution, if
* any, must include the following acknowlegement:
* "This product includes software developed by the
* Apache Software Foundation (http://www.apache.org/)."
@@ -92,7 +92,7 @@
*
* @version $Id$
*
- * @todo need suspend/resume facilities.
+ * @todo need suspendSegment/resumeSegment facilities.
*/
public class AvalonLifecycleHandler
extends AbstractLifecycleHandler
@@ -104,10 +104,10 @@
/** */
public static String SERVICE_MANAGER = "service.manager";
- List start;
- List suspend;
- List resume;
- List end;
+ List beginSegment;
+ List suspendSegment;
+ List resumeSegment;
+ List endSegment;
// ----------------------------------------------------------------------
// Constructors
@@ -124,41 +124,41 @@
// same package would probably do and be good for j2me environments. We'll avoid
// XML where we can.
- start = new ArrayList();
- suspend = new ArrayList();
- resume = new ArrayList();
- end = new ArrayList();
+ beginSegment = new ArrayList();
+ suspendSegment = new ArrayList();
+ resumeSegment = new ArrayList();
+ endSegment = new ArrayList();
- start.add( new LogEnablePhase() );
- start.add( new ContextualizePhase() );
- start.add( new ServicePhase() );
- start.add( new ConfigurePhase() );
- start.add( new ParameterizePhase() );
- start.add( new InitializePhase() );
- start.add( new StartPhase() );
+ beginSegment.add( new LogEnablePhase() );
+ beginSegment.add( new ContextualizePhase() );
+ beginSegment.add( new ServicePhase() );
+ beginSegment.add( new ConfigurePhase() );
+ beginSegment.add( new ParameterizePhase() );
+ beginSegment.add( new InitializePhase() );
+ beginSegment.add( new StartPhase() );
- suspend.add( new SuspendPhase() );
- suspend.add( new RecontextualizePhase() );
- suspend.add( new ReconfigurePhase() );
- suspend.add( new ReparameterizePhase() );
+ suspendSegment.add( new SuspendPhase() );
+ suspendSegment.add( new RecontextualizePhase() );
+ suspendSegment.add( new ReconfigurePhase() );
+ suspendSegment.add( new ReparameterizePhase() );
- resume.add( new ResumePhase() );
+ resumeSegment.add( new ResumePhase() );
- end.add( new StopPhase() );
- end.add( new DisposePhase() );
+ endSegment.add( new StopPhase() );
+ endSegment.add( new DisposePhase() );
}
/** Start a component's lifecycle.
*
* @param service The component service.
*
* @throws java.lang.Exception If an error occurs while attempting to start
* the component's lifecycle.
*/
public void startLifecycle( ServiceCapsule service )
throws Exception
{
- for ( Iterator i = start.iterator(); i.hasNext(); )
+ for ( Iterator i = beginSegment.iterator(); i.hasNext(); )
{
Phase phase = (Phase) i.next();
phase.execute( service, this );
@@ -169,13 +169,13 @@
*
* @param service The component service.
*
* @throws java.lang.Exception If an error occurs while attempting to end
* the component's lifecycle.
*/
public void endLifecycle( ServiceCapsule service )
throws Exception
{
- for ( Iterator i = end.iterator(); i.hasNext(); )
+ for ( Iterator i = endSegment.iterator(); i.hasNext(); )
{
Phase phase = (Phase) i.next();
phase.execute( service, this );
@@ -18,7 +18,7 @@
* distribution.
*
- * 3. The end-user documentation included with the redistribution, if
+ * 3. The endSegment-user documentation included with the redistribution, if
* any, must include the following acknowlegement:
* "This product includes software developed by the
@@ -124,41 +124,41 @@
* @param service The component service.
*
- * @throws java.lang.Exception If an error occurs while attempting to start
+ * @throws java.lang.Exception If an error occurs while attempting to beginSegment
* the component's lifecycle.
*/
@@ -169,13 +169,13 @@
* @param service The component service.
*
- * @throws java.lang.Exception If an error occurs while attempting to end
+ * @throws java.lang.Exception If an error occurs while attempting to endSegment
* the component's lifecycle.
*/
lmpx.com only provides a reader for public news (NNTP) servers. It is not
affiliated with the servers or forums shown here and is not responsible for
the content of articles, which is written by their respective authors.